==> dinolib-0.9.3.tar.gz: dinolib-0.9.3/lib/form/of_radio2.inc.php <==
<?php
/* OOHForms: radio
 * 
 * Copyright (c) 1998 by Jay Bloodworth
 * This file is modified by Dino Co.,Ltd.
 *
 * $Id: of_radio2.inc.php,v 1.1 2003/03/20 13:34:07 nishina Exp $
 */

/**
 * OOHForms: radio
 *
 *
 * @package Dino_Form
 * @access public
 */

class of_radio2 extends of_element {

  var $valid_e;
  var $options;

  // Constructor
  function of_radio2($a) {
    $this->setup_element($a);
  }

  function self_get($val, $which, &$count ) {
    $str = "";
    foreach ($this->options as $k => $v) {
      $str .= "<input type='radio' name='$this->name' value='";
      $str .= htmlspecialchars($v["value"], ENT_QUOTES) . "'";
      if ($this->extrahtml) 
	$str .= " $this->extrahtml";
      if ($v["value"]==$GLOBALS[$this->name]) 
	$str .= " checked";
      $str .= " /> ".$v["label"];
      $str .= "<br>\n";
      $count++;
    }
    //ǸβԤ
    $str = substr($str, 0, strlen($str)-strlen("<br>\n")); 
    return $str;
  }

  function self_get_frozen($val, $which, &$count) {
    //    if ($this->value==$val) {
    //      $x = 1;
    //      $str .= "<input type='hidden' name='$this->name' value='";
    //      $str .= htmlspecialchars($val, ENT_QUOTES) . "' />\n";
    //      $str .= "(*) ";
    //    } else {
    //      $str .= "(&nbsp;) ";
    //    }

    $str = "";    
    foreach ($this->options as $k => $v) {
      //
      if ($v["value"]==$GLOBALS[$this->name]) {
	$str .= "<input type='hidden' name='$this->name' value='";
	$str .= htmlspecialchars($v["value"], ENT_QUOTES) . "'";
	if ($this->extrahtml)
	  $str .= " $this->extrahtml";
	$str .= " /> "." (ߧ) ".$v["label"];
	$str .= "<br>\n";
	$count++;
      }else{
	$str .= "(&nbsp;) ${v["label"]}<br>\n";
      }
    }
    //ǸβԤ
    $str = substr($str, 0, strlen($str)-strlen("<br>\n")); 
    return $str;
  }

  function self_get_js($ndx_array) {
    $str = "";
    
    if ($this->valid_e) {
      $n = $this->name;
      $str .= "var l = f.elements['${n}'].length;\n";
      $str .= "var radioOK = false;\n";
      $str .= "for (i=0; i<l; i++)\n";
      $str .= "  if (f.elements['${n}'][i].checked) {\n";
      $str .= "    radioOK = true;\n";
      $str .= "    break;\n";
      $str .= "  }\n";
      $str .= "if (!radioOK) {\n";
      $str .= "  alert(\"$this->valid_e\");\n";
      $str .= "  return(false);\n";
      $str .= "}\n";
    }
  }

  function self_validate($val) {
    if ($this->valid_e && !isset($val)) return $this->valid_e;
    return false;
  }

} // end RADIO

?>

==> dinolib-0.9.4.tar.gz: dinolib-0.9.4/lib/form/of_radio2.inc.php <==
<?php
/* OOHForms: radio
 * 
 * Copyright (c) 1998 by Jay Bloodworth
 * This file is modified by Dino Co.,Ltd.
 *
 * $Id: of_radio2.inc.php,v 1.3 2003/11/13 14:19:59 shota Exp $
 */

/**
 * OOHForms: radio
 *
 *
 * @package Dino_Form
 * @access public
 */

class of_radio2 extends of_element {

  var $valid_e;
  var $options;

  // Constructor
  function of_radio2($a) {
    $this->setup_element($a);
  }

  function self_get($val, $which, &$count ) {
    $str = "";
    foreach ($this->options as $k => $v) {
      $str .= "<input type='radio' name='$this->name' value='";
      $str .= htmlspecialchars($v["value"], ENT_QUOTES) . "'";
      if ($this->extrahtml) 
	$str .= " $this->extrahtml";
      if ($v["value"]==$GLOBALS[$this->name]) 
	$str .= " checked";
      $str .= " /> ".$v["label"];
      $str .= "<br>\n";
      
      $count++;
    }
    //ǸβԤ
    $str = substr($str, 0, strlen($str)-strlen("<br>\n")); 
    return $str;
  }

  function self_get_frozen($val, $which, &$count, $hidden = false) {
    //    if ($this->value==$val) {
    //      $x = 1;
    //      $str .= "<input type='hidden' name='$this->name' value='";
    //      $str .= htmlspecialchars($val, ENT_QUOTES) . "' />\n";
    //      $str .= "(*) ";
    //    } else {
    //      $str .= "(&nbsp;) ";
    //    }

    $str = "";    
    foreach ($this->options as $k => $v) {
      //
      if ($v["value"]==$GLOBALS[$this->name]) {
	$str .= "<input type='hidden' name='$this->name' value='";
	$str .= htmlspecialchars($v["value"], ENT_QUOTES) . "'";
	if ($this->extrahtml)
	  $str .= " $this->extrahtml";
	//$str .= " /> "." (ߧ) ".$v["label"];
	$str .= " /> ";
    if ($hidden) {
      // never output *visible* HTML
	} else {
	  $str .= $v["label"];
	}
	$str .= "<br>\n";
	$count++;
      }else{
	//nn?
	//$str .= "(&nbsp;) ${v["label"]}<br>\n";
      }
    }
    //ǸβԤ
    $str = substr($str, 0, strlen($str)-strlen("<br>\n")); 
    return $str;
  }

  function self_get_js($ndx_array) {
    $str = "";
    
    if ($this->valid_e) {
      $n = $this->name;
      $str .= "var l = f.elements['${n}'].length;\n";
      $str .= "var radioOK = false;\n";
      $str .= "for (i=0; i<l; i++)\n";
      $str .= "  if (f.elements['${n}'][i].checked) {\n";
      $str .= "    radioOK = true;\n";
      $str .= "    break;\n";
      $str .= "  }\n";
      $str .= "if (!radioOK) {\n";
      $str .= "  alert(\"$this->valid_e\");\n";
      $str .= "  return(false);\n";
      $str .= "}\n";
    }
  }

  function self_validate($val) {
    if ($this->valid_e && !isset($val)) return $this->valid_e;
    return false;
  }

} // end RADIO

?>
